==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTextFieldUI.h <==
// public class javax.swing.plaf.basic.BasicTextFieldUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class cb49ffe0ee4d13c javax_swing_plaf_TextUI
// @dep_class c96b86492c177195 javax_swing_plaf_basic_BasicTextFieldUI
// @dep_class d214d118732d43a9 javax_swing_plaf_basic_BasicTextUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicTextUI

#include "javax/swing/plaf/basic/BasicTextUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTextFieldUI_H_
#define _JC_javax_swing_plaf_basic_BasicTextFieldUI_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;
struct _jc_javax_swing_text_Element$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_refs	_jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$refs	_jc_javax_swing_plaf_basic_BasicTextFieldUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$nonrefs	_jc_javax_swing_plaf_basic_BasicTextFieldUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object	_jc_javax_swing_plaf_basic_BasicTextFieldUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$vmethods	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$vtable	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$vtype	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTextFieldUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *);

// Virtual methods
extern struct _jc_javax_swing_text_View$object *_jc_javax_swing_plaf_basic_BasicTextFieldUI$method$create$cf4235120765a02e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_plaf_basic_BasicTextFieldUI$method$getPropertyPrefix$e7baa4035901c9a7(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicTextFieldUI$method$installUI$ddb69f0251b0939f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *, struct _jc_javax_swing_JComponent$object *);
extern void _jc_javax_swing_plaf_basic_BasicTextFieldUI$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *, struct _jc_java_beans_PropertyChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextFieldUI$method_info$create$cf4235120765a02e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextFieldUI$method_info$getPropertyPrefix$e7baa4035901c9a7;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextFieldUI$method_info$installUI$ddb69f0251b0939f;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextFieldUI$method_info$propertyChange$6d3500eaa79bf44b;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicTextFieldUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$vmethods {
	struct _jc_javax_swing_text_View$object	*(*create$cf4235120765a02e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*getPropertyPrefix$e7baa4035901c9a7)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *);
	void	(*installUI$ddb69f0251b0939f)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *, struct _jc_javax_swing_JComponent$object *);
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *, struct _jc_java_beans_PropertyChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TextUI$vmethods	javax_swing_plaf_TextUI;
	_jc_javax_swing_plaf_basic_BasicTextUI$vmethods	javax_swing_plaf_basic_BasicTextUI;
	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vmethods	javax_swing_plaf_basic_BasicTextFieldUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$refs {
    _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_refs	javax_swing_plaf_basic_BasicTextFieldUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_refs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_TextUI$sub_refs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TextUI$sub_nonrefs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextFieldUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object {
	_jc_javax_swing_plaf_basic_BasicTextFieldUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTextFieldUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTextFieldUI$vtype _jc_javax_swing_plaf_basic_BasicTextFieldUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTextFieldUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTextFieldUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTextFieldUI_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTextFieldUI.h <==
// public class javax.swing.plaf.basic.BasicTextFieldUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class cb49ffe0ee4d13c javax_swing_plaf_TextUI
// @dep_class c96b86492c177195 javax_swing_plaf_basic_BasicTextFieldUI
// @dep_class d214d118732d43a9 javax_swing_plaf_basic_BasicTextUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicTextUI

#include "javax/swing/plaf/basic/BasicTextUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTextFieldUI_H_
#define _JC_javax_swing_plaf_basic_BasicTextFieldUI_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;
struct _jc_javax_swing_text_Element$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_refs	_jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$refs	_jc_javax_swing_plaf_basic_BasicTextFieldUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$nonrefs	_jc_javax_swing_plaf_basic_BasicTextFieldUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object	_jc_javax_swing_plaf_basic_BasicTextFieldUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$vmethods	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$vtable	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$vtype	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTextFieldUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_text_View$object *_jc_javax_swing_plaf_basic_BasicTextFieldUI$method$create$cf4235120765a02e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_plaf_basic_BasicTextFieldUI$method$getPropertyPrefix$e7baa4035901c9a7(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicTextFieldUI$method$installUI$ddb69f0251b0939f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicTextFieldUI$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextFieldUI$method_info$create$cf4235120765a02e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextFieldUI$method_info$getPropertyPrefix$e7baa4035901c9a7;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextFieldUI$method_info$installUI$ddb69f0251b0939f;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextFieldUI$method_info$propertyChange$6d3500eaa79bf44b;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicTextFieldUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$vmethods {
	struct _jc_javax_swing_text_View$object	*(*create$cf4235120765a02e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPropertyPrefix$e7baa4035901c9a7)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *) _JC_JCNI_ATTR;
	void	(*installUI$ddb69f0251b0939f)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TextUI$vmethods	javax_swing_plaf_TextUI;
	_jc_javax_swing_plaf_basic_BasicTextUI$vmethods	javax_swing_plaf_basic_BasicTextUI;
	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vmethods	javax_swing_plaf_basic_BasicTextFieldUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$refs {
    _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_refs	javax_swing_plaf_basic_BasicTextFieldUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_refs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_TextUI$sub_refs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TextUI$sub_nonrefs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextFieldUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTextFieldUI$object {
	_jc_javax_swing_plaf_basic_BasicTextFieldUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTextFieldUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTextFieldUI$vtype _jc_javax_swing_plaf_basic_BasicTextFieldUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTextFieldUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTextFieldUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTextFieldUI_H_ */
